//#extension GL_OES_standard_derivatives : enable

uniform sampler2D Texture1;
uniform sampler2D Texture2;

varying mediump vec2 myTexCoord;
varying mediump vec4 myTexColor;

uniform mediump vec4 screenParams;  //[0] = w, [1] = h, [2] = 1/w, [3] = 1/h
uniform mediump vec2 borderParams;  //[0] = frac of screen size height; [1] = 1/frac of screen size height
uniform mediump vec4 effect_color;  //r,g,b = border color, a = effect amount

float getEffectAmount()
{
	vec2 screenSize = screenParams.xy;
	float screenHeight = screenParams.y;
	float borderFrac = borderParams.x;
	float borderSize = screenHeight * borderFrac;
	
	if (gl_FragCoord.x < borderSize || gl_FragCoord.y < borderSize || gl_FragCoord.x > screenSize.x - borderSize || gl_FragCoord.y > screenSize.y - borderSize)
	{
		float invScreenHeight = screenParams.w;
		float invBorderFrac = borderParams.y;
		float invBorderSize = invScreenHeight * invBorderFrac;

		float fracX = 0.0;
		if (gl_FragCoord.x < borderSize)
			fracX = 1.0 - gl_FragCoord.x * invBorderSize;
		else
		if (gl_FragCoord.x > screenSize.x - borderSize)
			fracX = 1.0 - (screenSize.x - gl_FragCoord.x) * invBorderSize;
		else
			fracX = 0.0;

		float fracY = 0.0;
		if (gl_FragCoord.y < borderSize)
			fracY = 1.0 - gl_FragCoord.y * invBorderSize;
		else
		if (gl_FragCoord.y > screenSize.y - borderSize)
			fracY = 1.0 - (screenSize.y - gl_FragCoord.y) * invBorderSize;
		else
			fracY = 0.0;
				
		float frac = fracX * fracX + fracY * fracY;
		return frac;
	}
	return 0.0;
}

void main (void)
{
	vec4 color = myTexColor * texture2D(Texture1, myTexCoord);
	
	if (effect_color.a > 0.0)
	{
		float frac = getEffectAmount();
			
		if (frac > 0.0)
		{
			float effAmount = effect_color.a * frac;
			vec3 sumColor = color.rgb + effect_color.rgb * effAmount;
				
			sumColor = clamp(sumColor, 0.0, 1.0);
				
			color = vec4(sumColor.rgb, color.a);
		}
	}
	
	gl_FragColor = color;
}

